GradientPresets class

Predefined gradient color schemes for easy use.

Constructors

GradientPresets()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

aurora → const List<Color>
Aurora gradient colors.
fire → const List<Color>
Fire gradient colors.
forest → const List<Color>
Forest gradient colors.
midnight → const List<Color>
Midnight gradient colors.
ocean → const List<Color>
Ocean gradient colors.
purpleDream → const List<Color>
Purple dream gradient colors.
sunset → const List<Color>
Sunset gradient colors.
tropical → const List<Color>
Tropical gradient colors.