LinearGradientDirection enum

The direction of a linear gradient.

Inheritance
Available extensions

Values

topLeftToBottomRight → const LinearGradientDirection

From top-left to bottom-right.

topRightToBottomLeft → const LinearGradientDirection

From top-right to bottom-left.

topToBottom → const LinearGradientDirection

From top to bottom.

bottomToTop → const LinearGradientDirection

From bottom to top.

leftToRight → const LinearGradientDirection

From left to right.

rightToLeft → const LinearGradientDirection

From right to left.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LinearGradientDirection>
A constant List of the values in this enum, in order of their declaration.